--DESCRIPTION
--This script displays the definition of a synonym.
--
--USAGE
--        @SHOW_SYN [owner.]synonym_name
--  
SET ECHO OFF 
SET VERIFY OFF
SET FEEDBACK OFF
 
--Disect the input argument, and get the owner name and
--table name into two seperate substitution variables.
--The owner name defaults to the current user.
SET TERMOUT OFF
DEFINE s_owner_name = ' '
DEFINE s_synonym_name = ' '
COLUMN owner_name NOPRINT NEW_VALUE s_owner_name
COLUMN synonym_name NOPRINT NEW_VALUE s_synonym_name
SELECT
  DECODE(INSTR('&&1','.'),
         0,USER,  /*Default to current user.*/
         UPPER(SUBSTR('&&1',1,INSTR('&&1','.')-1))) owner_name,
  DECODE(INSTR('&&1','.'),
         0,UPPER('&&1'),  /*Only the table name was passed in.*/
         UPPER(SUBSTR('&&1',INSTR('&&1','.')+1))) synonym_name
  FROM dual;          
CLEAR COLUMNS
SET TERMOUT ON

--Display information about the synonym
--Information is displayed in three lines to accomodate the 
--longest possible values for each data element.
--The matching public synonym, if one exists, is 
--always shown as well.
SET HEADING OFF
SET NEWPAGE NONE
SET PAGESIZE 0
SET RECSEP OFF
SET LINESIZE 80
COLUMN owner NOPRINT
COLUMN synonym_name NOPRINT
COLUMN syn_def FORMAT A80 word_wrapped
PROMPT
SELECT DECODE(owner,'PUBLIC','1' || owner,'2' || owner) owner,
       synonym_name,
       owner || '.' || synonym_name 
       || ' synonym for ' || table_owner || '.' || table_name
       || DECODE(db_link,NULL,NULL,CHR(10) || 'at ' || db_link) syn_def
  FROM all_synonyms
 WHERE owner = '&&s_owner_name'
   AND synonym_name = '&&s_synonym_name'
UNION
SELECT DECODE(owner,'PUBLIC','1' || owner,'2' || owner) owner, 
       synonym_name,
       synonym_name 
       || ' PUBLIC synonym for ' || table_owner || '.' || table_name
       || DECODE(db_link,NULL,NULL,CHR(10) || 'at ' || db_link) syn_def
  FROM all_synonyms
 WHERE owner = 'PUBLIC'
   AND synonym_name = '&&s_synonym_name'
ORDER BY owner,synonym_name;
 
--Reset everything back to its default.
CLEAR COLUMNS
UNDEFINE s_owner_name
UNDEFINE s_synonym_name
SET HEADING ON
SET NEWPAGE 1
SET PAGESIZE 14
SET VERIFY ON
SET RECSEP WRAPPED
SET FEEDBACK ON

