--DESCRIPTION
--Print one of three user security reports

SET FEEDBACK OFF
SET PAGESIZE 20
SET LINESIZE 77
SET HEADING ON

--Ask the user what report to print
PROMPT 
PROMPT 1 - List users
PROMPT 2 - List users and table privileges
PROMPT 3 - List users and system privileges
PROMPT
ACCEPT s_report_choice PROMPT 'Enter your choice (1,2,3) >'

--A PL/SQL block will set the b_report bind variable
--to a query based on the user's response. Text for the
--report title will be returned in b_report_type.
VARIABLE b_report REFCURSOR
VARIABLE b_report_type VARCHAR2(30)

--Interpret the user's choice.
BEGIN
  IF '&&s_report_choice' = '1' THEN
    --Return some text for the title to identify this report.
    :b_report_type := 'User Listing';

    --Return a query that will list all users.
    OPEN :b_report FOR 
      SELECT username 
        FROM dba_users
      ORDER BY username;
  ELSIF '&&s_report_choice' = '2' THEN
    --Return some text for the title to identify this report.
    :b_report_type := 'User Table Privileges';

    --Return a query that will list users and any
    --privileges they have on tables in the database.
    OPEN :b_report FOR
      SELECT username, privilege, owner, table_name
        FROM dba_users, dba_tab_privs
       WHERE username = grantee
      ORDER BY username, owner, table_name, privilege;
  ELSIF '&&s_report_choice' = '3' THEN
    --Return some text for the title to identify this report.
    :b_report_type := 'User System Privileges';

    --Return a query that lists users and any system
    --privileges that they have been granted.
    OPEN :b_report FOR 
      SELECT username, privilege
        FROM dba_users, dba_sys_privs
       WHERE username = grantee
      ORDER BY username, privilege;
  ELSE
    --Return some text for the title to identify this report.
    :b_report_type := 'Invalid Report Choice';

    --The user made an invalid choice, so
    --return a query that will display an error message.
    OPEN :b_report FOR 
      SELECT 'You must choose either 1, 2, or 3' error_message
        FROM dual;
  END IF;
END;
/ 

--Specify formats for all possible report columns.
COLUMN username FORMAT A12 HEADING 'User'
COLUMN privilege FORMAT A20 HEADING 'Privilege'
COLUMN owner FORMAT A12 HEADING 'Table Owner'
COLUMN table_name FORMAT A30 HEADING 'Table Name'
COLUMN error_message FORMAT A40 HEADING 'Error Message'

--Setup the page title. First we have to get the contents of 
--b_report_type into a substition variable.
set termout off
COLUMN b_report_type FORMAT A30 NOPRINT NEW_VALUE s_report_type
SELECT b_report_type FROM dual;
set termout on

TTITLE LEFT s_report_type RIGHT 'Page ' FORMAT 999 SQL.PNO SKIP 2

--Run the report requested by the user
PRINT b_report

